@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcefileloader.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2005 - Paolo Maggi
@@ -26,13 +26,13 @@
 #endif
 
 #include "gtksourcefileloader.h"
+#include <glib/gi18n-lib.h>
 #include "gtksourcebuffer.h"
 #include "gtksourcefile.h"
 #include "gtksourcebufferoutputstream.h"
 #include "gtksourceencoding.h"
 #include "gtksourceencoding-private.h"
-#include "gtksourceview-enumtypes.h"
-#include "gtksourceview-i18n.h"
+#include "gtksource-enumtypes.h"
 
 /**
  * SECTION:fileloader
