@@ -25,7 +25,9 @@
 #include "gtksourcegutterrenderer.h"
 #include "gtksourcegutterrenderer-private.h"
 #include "gtksourcestylescheme.h"
+#include "gtksourceview.h"
 #include "gtksource-enumtypes.h"
+#include "gtksource-marshal.h"
 
 /**
  * SECTION:gutterrenderer
@@ -614,12 +616,16 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (GtkSourceGutterRendererClass, activate),
-		              NULL, NULL, NULL,
+		              NULL, NULL,
+		              _gtk_source_marshal_VOID__BOXED_BOXED_BOXED,
 		              G_TYPE_NONE,
 		              3,
 		              GTK_TYPE_TEXT_ITER,
 		              GDK_TYPE_RECTANGLE,
 		              GDK_TYPE_EVENT);
+	g_signal_set_va_marshaller (signals[ACTIVATE],
+	                            G_TYPE_FROM_CLASS (klass),
+	                            _gtk_source_marshal_VOID__BOXED_BOXED_BOXEDv);
 
 	/**
 	 * GtkSourceGutterRenderer::queue-draw:
@@ -635,8 +641,12 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (GtkSourceGutterRendererClass, queue_draw),
-		              NULL, NULL, NULL,
+		              NULL, NULL,
+		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE, 0);
+	g_signal_set_va_marshaller (signals[QUEUE_DRAW],
+	                            G_TYPE_FROM_CLASS (klass),
+	                            g_cclosure_marshal_VOID__VOIDv);
 
 	/**
 	 * GtkSourceGutterRenderer::query-tooltip:
@@ -658,7 +668,7 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_STRUCT_OFFSET (GtkSourceGutterRendererClass, query_tooltip),
 		              g_signal_accumulator_true_handled,
 		              NULL,
-		              NULL,
+		              _gtk_source_marshal_BOOLEAN__BOXED_BOXED_INT_INT_OBJECT,
 		              G_TYPE_BOOLEAN,
 		              5,
 		              GTK_TYPE_TEXT_ITER,
@@ -666,6 +676,9 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_TYPE_INT,
 		              G_TYPE_INT,
 		              GTK_TYPE_TOOLTIP);
+	g_signal_set_va_marshaller (signals[QUERY_TOOLTIP],
+	                            G_TYPE_FROM_CLASS (klass),
+	                            _gtk_source_marshal_BOOLEAN__BOXED_BOXED_INT_INT_OBJECTv);
 
 	/**
 	 * GtkSourceGutterRenderer::query-data:
@@ -685,12 +698,16 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (GtkSourceGutterRendererClass, query_data),
-		              NULL, NULL, NULL,
+		              NULL, NULL,
+			      _gtk_source_marshal_VOID__BOXED_BOXED_FLAGS,
 		              G_TYPE_NONE,
 		              3,
 		              GTK_TYPE_TEXT_ITER,
 		              GTK_TYPE_TEXT_ITER,
 		              GTK_SOURCE_TYPE_GUTTER_RENDERER_STATE);
+	g_signal_set_va_marshaller (signals[QUERY_DATA],
+	                            G_TYPE_FROM_CLASS (klass),
+	                            _gtk_source_marshal_VOID__BOXED_BOXED_FLAGSv);
 
 	/**
 	 * GtkSourceGutterRenderer::query-activatable:
@@ -710,12 +727,15 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 		              G_STRUCT_OFFSET (GtkSourceGutterRendererClass, query_activatable),
 		              g_signal_accumulator_true_handled,
 		              NULL,
-		              NULL,
+		              _gtk_source_marshal_BOOLEAN__BOXED_BOXED_BOXED,
 		              G_TYPE_BOOLEAN,
 		              3,
 		              GTK_TYPE_TEXT_ITER,
 		              GDK_TYPE_RECTANGLE,
 		              GDK_TYPE_EVENT);
+	g_signal_set_va_marshaller (signals[QUERY_ACTIVATABLE],
+	                            G_TYPE_FROM_CLASS (klass),
+	                            _gtk_source_marshal_BOOLEAN__BOXED_BOXED_BOXEDv);
 
 	/**
 	 * GtkSourceGutterRenderer:view:
