@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcestyle.c
+ *
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2003 - Paolo Maggi <paolo.maggi@polito.it>
@@ -24,7 +24,6 @@
 
 #include "gtksourcestyle.h"
 #include "gtksourcestyle-private.h"
-#include "gtksourceview-i18n.h"
 
 /**
  * SECTION:style
