@@ -1,24 +1,26 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtk_sourcesourcestyleschemechooser.c
- * This file is part of gtk_sourcesourceview
+ *
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2014 - Ignacio Casal Quinteiro
  *
- * gtk_sourcesourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtk_sourcesourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with gtk_sourcesourceview. If not, see <http://www.gnu.org/licenses/>.
+ * along with GtkSourceView. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include "gtksourcestyleschemechooser.h"
 #include "gtksourcestylescheme.h"
